==> blancoStringConverter-0.1.0-src.zip: blancoStringConverter/blanco.python/main/blanco/sample/stringconverter/SampleZenHiragana2KatakanaStringConverter.py <==
# -*- coding: cp932 -*-
"""̃\[XR[h blanco FrameworkɂĎĂ܂B
"""
class SampleZenHiragana2KatakanaStringConverter:
    """SpЂ炪ȁSpJ^Ji̕ϊ̃TvBblancoStringConverter̎ɂ͉e܂B
    """

    """u`B
    """
    STRING_CONVERT_DEF = [[ 'J', '' ]
, [ '', '@' ]
, [ '', 'A' ]
, [ '', 'B' ]
, [ '', 'C' ]
, [ '', 'D' ]
, [ '', 'E' ]
, [ '', 'F' ]
, [ '', 'G' ]
, [ '', 'H' ]
, [ '', 'I' ]
, [ '', 'J' ]
, [ '', 'K' ]
, [ '', 'L' ]
, [ '', 'M' ]
, [ '', 'N' ]
, [ '', 'O' ]
, [ '', 'P' ]
, [ '', 'Q' ]
, [ '', 'R' ]
, [ '', 'S' ]
, [ '', 'T' ]
, [ '', 'U' ]
, [ '', 'V' ]
, [ '', 'W' ]
, [ '', 'X' ]
, [ '', 'Y' ]
, [ '', 'Z' ]
, [ '', '[' ]
, [ '', '\' ]
, [ '', ']' ]
, [ '', '^' ]
, [ '', '_' ]
, [ '', '`' ]
, [ '', 'a' ]
, [ '', 'b' ]
, [ '', 'c' ]
, [ '', 'd' ]
, [ '', 'e' ]
, [ '', 'f' ]
, [ '', 'g' ]
, [ '', 'h' ]
, [ '', 'i' ]
, [ '', 'j' ]
, [ '', 'k' ]
, [ '', 'l' ]
, [ '', 'm' ]
, [ '', 'n' ]
, [ '', 'o' ]
, [ '', 'p' ]
, [ '', 'q' ]
, [ '', 'r' ]
, [ '', 's' ]
, [ '', 't' ]
, [ '', 'u' ]
, [ '', 'v' ]
, [ '', 'w' ]
, [ '', 'x' ]
, [ '', 'y' ]
, [ '', 'z' ]
, [ '', '{' ]
, [ '', '|' ]
, [ '', '}' ]
, [ '', '~' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
 ]

    def convert(self, argCheck):
        """ϊ`ɏ]Aϊ܂B

        self -- ̃\bh܂ރNXgB
        argCheck -- ϊΏۂ̕B
        return -- ϊ`ɂĕϊꂽBϊ`ɂЂƂvȂꍇɂ͌̕񂪖߂܂B
        """
        if argCheck is None:
            raise "\bh[convert]̃p[^[argCheck]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        wrkString = ''
        index = 0
        while index < len(argCheck):
            look = argCheck[index:]
            isFound = False
            for indexDef in range(len(self.STRING_CONVERT_DEF)):
                if look.find(self.STRING_CONVERT_DEF[indexDef][0]) == 0:
                    wrkString += self.STRING_CONVERT_DEF[indexDef][1]
                    index += len(self.STRING_CONVERT_DEF[indexDef][0])
                    isFound = True
                    break
                #end
            #end
            if isFound == False:
                wrkString += unicode(argCheck[index:])[0].encode()
                index = index + len(unicode(argCheck[index:])[0].encode())
            #end
        #end

        return wrkString
    #end
#end

==> blancoStringConverter-0.1.1-src.zip: blancoStringConverter/blanco.python/main/blanco/sample/stringconverter/SampleZenHiragana2KatakanaStringConverter.py <==
# -*- coding: cp932 -*-
"""̃\[XR[h blanco FrameworkɂĎĂ܂B
"""
class SampleZenHiragana2KatakanaStringConverter:
    """SpЂ炪ȁSpJ^Ji̕ϊ̃TvBblancoStringConverter̎ɂ͉e܂B
    """

    """u`B
    """
    STRING_CONVERT_DEF = [[ 'J', '' ]
, [ '', '@' ]
, [ '', 'A' ]
, [ '', 'B' ]
, [ '', 'C' ]
, [ '', 'D' ]
, [ '', 'E' ]
, [ '', 'F' ]
, [ '', 'G' ]
, [ '', 'H' ]
, [ '', 'I' ]
, [ '', 'J' ]
, [ '', 'K' ]
, [ '', 'L' ]
, [ '', 'M' ]
, [ '', 'N' ]
, [ '', 'O' ]
, [ '', 'P' ]
, [ '', 'Q' ]
, [ '', 'R' ]
, [ '', 'S' ]
, [ '', 'T' ]
, [ '', 'U' ]
, [ '', 'V' ]
, [ '', 'W' ]
, [ '', 'X' ]
, [ '', 'Y' ]
, [ '', 'Z' ]
, [ '', '[' ]
, [ '', '\' ]
, [ '', ']' ]
, [ '', '^' ]
, [ '', '_' ]
, [ '', '`' ]
, [ '', 'a' ]
, [ '', 'b' ]
, [ '', 'c' ]
, [ '', 'd' ]
, [ '', 'e' ]
, [ '', 'f' ]
, [ '', 'g' ]
, [ '', 'h' ]
, [ '', 'i' ]
, [ '', 'j' ]
, [ '', 'k' ]
, [ '', 'l' ]
, [ '', 'm' ]
, [ '', 'n' ]
, [ '', 'o' ]
, [ '', 'p' ]
, [ '', 'q' ]
, [ '', 'r' ]
, [ '', 's' ]
, [ '', 't' ]
, [ '', 'u' ]
, [ '', 'v' ]
, [ '', 'w' ]
, [ '', 'x' ]
, [ '', 'y' ]
, [ '', 'z' ]
, [ '', '{' ]
, [ '', '|' ]
, [ '', '}' ]
, [ '', '~' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
 ]

    def convert(self, argCheck):
        """ϊ`ɏ]Aϊ܂B

        self -- ̃\bh܂ރNXgB
        argCheck -- ϊΏۂ̕B
        return -- ϊ`ɂĕϊꂽBϊ`ɂЂƂvȂꍇɂ͌̕񂪖߂܂B
        """
        if argCheck is None:
            raise ValueError, "\bh[convert]̃p[^[argCheck]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        wrkString = ''
        index = 0
        while index < len(argCheck):
            look = argCheck[index:]
            isFound = False
            for indexDef in range(len(self.STRING_CONVERT_DEF)):
                if look.find(self.STRING_CONVERT_DEF[indexDef][0]) == 0:
                    wrkString += self.STRING_CONVERT_DEF[indexDef][1]
                    index += len(self.STRING_CONVERT_DEF[indexDef][0])
                    isFound = True
                    break
                #end
            #end
            if isFound == False:
                wrkString += unicode(argCheck[index:])[0].encode()
                index = index + len(unicode(argCheck[index:])[0].encode())
            #end
        #end

        return wrkString
    #end
#end
